Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1078)

Unified Diff: webkit/fileapi/file_system_mount_point_provider.h

Issue 10823273: Integrate external mount points to IsolatedContext (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: wording fix Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/fileapi/file_system_mount_point_provider.h
diff --git a/webkit/fileapi/file_system_mount_point_provider.h b/webkit/fileapi/file_system_mount_point_provider.h
index fbc7b58d475eec53f9647b5e76bcf0271e038f28..6d9c8da15beb162e114d0428e40f5d9dc683b4b1 100644
--- a/webkit/fileapi/file_system_mount_point_provider.h
+++ b/webkit/fileapi/file_system_mount_point_provider.h
@@ -122,18 +122,24 @@ class FILEAPI_EXPORT FileSystemMountPointProvider {
class ExternalFileSystemMountPointProvider
: public FileSystemMountPointProvider {
public:
- // Returns the list of top level directories that are exposed by this
- // provider. This list is used to set appropriate child process file access
- // permissions.
- virtual std::vector<FilePath> GetRootDirectories() const = 0;
- // Grant access to all external file system from extension identified with
+ // A struct used to represent an external mount point.
+ struct MountInfo {
+ std::string mount_name;
+ FilePath root_path;
+ };
+
+ // Returns the list of mount names and associated directories that are
+ // exposed by this provider. This list is used to set appropriate child
+ // process file access permissions.
+ virtual std::vector<MountInfo> GetMountPoints() const = 0;
+ // Grants access to all external file system from extension identified with
// |extension_id|.
virtual void GrantFullAccessToExtension(const std::string& extension_id) = 0;
// Grants access to |virtual_path| from |origin_url|.
virtual void GrantFileAccessToExtension(
const std::string& extension_id,
const FilePath& virtual_path) = 0;
- // Revoke file access from extension identified with |extension_id|.
+ // Revokes file access from extension identified with |extension_id|.
virtual void RevokeAccessForExtension(
const std::string& extension_id) = 0;
// Checks if a given |mount_point| already exists.
@@ -144,7 +150,7 @@ class ExternalFileSystemMountPointProvider
virtual void AddRemoteMountPoint(
const FilePath& mount_point,
RemoteFileSystemProxyInterface* remote_proxy) = 0;
- // Remove a mount point.
+ // Removes a mount point.
virtual void RemoveMountPoint(const FilePath& mount_point) = 0;
// Gets virtual path by known filesystem path. Returns false when filesystem
// path is not exposed by this provider.

Powered by Google App Engine
This is Rietveld 408576698